package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````,`*``!````W!4``#0```!@D0````0`!30`(``'
M`"@`%P`6``8````T````-````#0```#@````X`````4````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````Y(``
M`.2````%```````!``$```"XC0``N(T!`+B-`0"@`@``T!(```8```````$`
M`@```,2-``#$C0$`Q(T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&2XC0``N(T!`+B-`0!(`@``2`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```%`````(````"```
M``&````E0`2`*(`0`:"&4("``0``"R`$C3B`$D&*!`@(4````%$```!5````
M6@```%L```!A````8@```&,`````````90``````````````9@```&<```!I
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;^)'Q@%8[Y=YN^.2?%7#/-)GK\QFB`=P
MTT-%U>PS8MOM?ZF<F^"G`@J_VE<;H^#[20``````````````````````````
M9!`````````#``<``````,"-`0```````P`/``P``````````````!(```#G
M`0`````````````2````%```````````````$0````T"`````````````!$`
M``")`0`````````````2````&P``````````````$@```,8!````````````
M`!(````C```````````````2````*@``````````````$@```!H"````````
M`````!(```#2`0`````````````2````,P``````````````(````&(#````
M`````````"$```!+```````````````2````40``````````````$@```%@`
M`````````````!(````H`P`````````````2````&0,`````````````$@``
M`)\"`````````````!(```!?```````````````2````0`(`````````````
M$@```&8``````````````!(```#4`@`````````````2````;0``````````
M````$@```'4``````````````"````")```````````````2````O0(`````
M````````$@```)$``````````````!(```"7```````````````2````H```
M````````````(````!(#`````````````!(```"\```````````````2````
MP0``````````````$@```"L"`````````````!$```#;`@`````````````2
M````;0(`````````````$@```#@#`````````````!(```!?`@``````````
M```2````W@,`````````````$@```.8"`````````````!$```!A`P``````
M```````1````D0(`````````````$@```$X#`````````````!(```!C`P``
M```````````1````R```````````````$@```$8#`````````````!(```#1
M```````````````1````EP$`````````````$@```.,``````````````"(`
M``#R```````````````@````"`$`````````````$@````H#````````````
M`!(```!]`@`````````````2````#0$`````````````$@```!,!````````
M`````"````#(`@`````````````2````+0$`````````````$@```+<!````
M`````````!(````R`0`````````````2````K0(`````````````$@```*8!
M`````````````!(````X`0`````````````2````20$`````````````$@``
M`#L"`````````````!(```"2```````````````2````3`(`````````````
M$@```(8"`````````````!(````_`P`````````````2````3P$`````````
M````$@```#`#`````````````!(```!C`0`````````````2````-@(`````
M````````$@```/4!`````````````!(```!J`0`````````````2````<0$`
M````````````$@```&`#`````````````"$```""`0`````````````2````
MC0,``(B@`0``````$``3`%L#``!L$P``<`(``!(`"0`'`@``2$````0````2
M``H`(`0``(0R``#8"0``$@`)`)8$``#P/P``6````!(`"0#]`P``7"L```0`
M```2``D`+P0``&00```$````$@`'`$,$``!</```E`,``!(`"0!^`P``6)`!
M```````0`!,`B00``&`K```D`@``$@`)`'(#``!8D`$``````!``$P`.!```
M>#$```P!```2``D`+00``%PI``!<````$@`)`#4$``#X,```:````!(`"0!C
M!```A"T``"`````2``D`F`,``(B@`0``````$``3`*`#``"(H`$``````!``
M$P##`P```!8``%P````2``D`<`0``*0M```4`0``$@`)`%D$``!4D`$`!```
M`!$`$@!K`P``6)`!```````0`!(`=P,``-P5````````$@`)`,P#``!@,0``
M&````!(`"0#G`P``)"H``#@!```2``D`C`,``(B@`0``````$``3`'P$``"X
M+@``0`(``!(`"0``;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L;&]C
M`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E
M:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!?2G9?4F5G
M:7-T97)#;&%S<V5S`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`')E861L:6YK`%]?<W1A
M8VM?8VAK7V=U87)D`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?
M:6YF;P!E>&ET`&-L;W-E`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A
M9`!R;61I<@!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`'!T:')E861?9V5T<W!E
M8VEF:6,`;65M8W!Y`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL`&=E='5I9`!0
M97)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`
M<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E
M>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!?9FEN:0!03%]D
M;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E
M90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P
M=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E
M<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R
M87``;&EB8RYM=7-L+6%R;6AF+G-O+C$`9G!R:6YT9@!S=')D=7``<'1H<F5A
M9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<F-H<@!S=')T;VL`<W1R;F-P
M>0!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S
M=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`7V5N9``O
M=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210!?<W1A<G1?8P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R
M7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`
M>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!M
M>5]P87)?<&P`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N
M=@!P87)?9FEN9'!R;V<`<&%R7V-L96%N=7````"XC0$`%P```+R-`0`7````
MN(\!`!<```#$CP$`%P```-2/`0`7`````)`!`!<````(D`$`%P````R0`0`7
M````$)`!`!<````4D`$`%P```!B0`0`7````')`!`!<````DD`$`%P```"B0
M`0`7````,)`!`!<````TD`$`%P```#B0`0`7````/)`!`!<```!`D`$`%P``
M`$B0`0`7````3)`!`!<```!4D`$`%P```+R/`0`5!0``P(\!`!4&``#(CP$`
M%0X``,R/`0`5&P``T(\!`!4@``#8CP$`%20``-R/`0`5*@``X(\!`!4N``#D
MCP$`%3$``.B/`0`5,P``[(\!`!4T``#PCP$`%3D``/2/`0`5/@``^(\!`!4_
M``#\CP$`%40``,".`0`6`P``Q(X!`!8$``#(C@$`%@<``,R.`0`6"```T(X!
M`!8)``#4C@$`%@H``-B.`0`6"P``W(X!`!8,``#@C@$`%@T``.2.`0`6#@``
MZ(X!`!80``#LC@$`%A$``/".`0`6$@``](X!`!83``#XC@$`%A0``/R.`0`6
M%0```(\!`!86```$CP$`%A<```B/`0`6&```#(\!`!89```0CP$`%AH``!2/
M`0`6'```&(\!`!8=```<CP$`%AX``""/`0`6'P``)(\!`!8A```HCP$`%B(`
M`"R/`0`6(P``,(\!`!8E```TCP$`%B8``#B/`0`6)P``/(\!`!8H``!`CP$`
M%BD``$2/`0`6+```2(\!`!8M``!,CP$`%B\``%"/`0`6,```5(\!`!8R``!8
MCP$`%C,``%R/`0`6-```8(\!`!8U``!DCP$`%C8``&B/`0`6-P``;(\!`!8X
M``!PCP$`%CH``'2/`0`6.P``>(\!`!8\``!\CP$`%CT``("/`0`60```A(\!
M`!9!``"(CP$`%D(``(R/`0`60P``D(\!`!9%``"4CP$`%D8``)B/`0`61P``
MG(\!`!9(``"@CP$`%DD``*2/`0`62@``J(\!`!9+``"LCP$`%DP``+"/`0`6
M30``M(\!`!9/```!0"WI`4"]Z![_+^$$X"WE!."?Y0[@C^`(\+[E-'X!``#&
MC^(7RHSB-/Z\Y0#&C^(7RHSB+/Z\Y0#&C^(7RHSB)/Z\Y0#&C^(7RHSB'/Z\
MY0#&C^(7RHSB%/Z\Y0#&C^(7RHSB#/Z\Y0#&C^(7RHSB!/Z\Y0#&C^(7RHSB
M_/V\Y0#&C^(7RHSB]/V\Y0#&C^(7RHSB[/V\Y0#&C^(7RHSBY/V\Y0#&C^(7
MRHSBW/V\Y0#&C^(7RHSBU/V\Y0#&C^(7RHSBS/V\Y0#&C^(7RHSBQ/V\Y0#&
MC^(7RHSBO/V\Y0#&C^(7RHSBM/V\Y0#&C^(7RHSBK/V\Y0#&C^(7RHSBI/V\
MY0#&C^(7RHSBG/V\Y0#&C^(7RHSBE/V\Y0#&C^(7RHSBC/V\Y0#&C^(7RHSB
MA/V\Y0#&C^(7RHSB?/V\Y0#&C^(7RHSB=/V\Y0#&C^(7RHSB;/V\Y0#&C^(7
MRHSB9/V\Y0#&C^(7RHSB7/V\Y0#&C^(7RHSB5/V\Y0#&C^(7RHSB3/V\Y0#&
MC^(7RHSB1/V\Y0#&C^(7RHSB//V\Y0#&C^(7RHSB-/V\Y0#&C^(7RHSB+/V\
MY0#&C^(7RHSB)/V\Y0#&C^(7RHSB'/V\Y0#&C^(7RHSB%/V\Y0#&C^(7RHSB
M#/V\Y0#&C^(7RHSB!/V\Y0#&C^(7RHSB_/R\Y0#&C^(7RHSB]/R\Y0#&C^(7
MRHSB[/R\Y0#&C^(7RHSBY/R\Y0#&C^(7RHSBW/R\Y0#&C^(7RHSBU/R\Y0#&
MC^(7RHSBS/R\Y0#&C^(7RHSBQ/R\Y0#&C^(7RHSBO/R\Y0#&C^(7RHSBM/R\
MY0#&C^(7RHSBK/R\Y0#&C^(7RHSBI/R\Y0#&C^(7RHSBG/R\Y0#&C^(7RHSB
ME/R\Y0#&C^(7RHSBC/R\Y0#&C^(7RHSBA/R\Y0#&C^(7RHSB?/R\Y0#&C^(7
MRHSB=/R\Y0#&C^(7RHSB;/R\Y0#&C^(7RHSB9/R\Y0#&C^(7RHSB7/R\Y0#&
MC^(7RHSB5/R\Y0#&C^(7RHSB3/R\Y7!`+>D@T$WB(#"-X@P@(^4#(*#A'`"-
MY1@0C>4<`(WB&!"-XOA!G^6I___K]#&?Y01`C^`#,)3G##"-Y>@QG^4,()WE
M`S"4YP(0H.$#`*#A$#"-Y5G__^O0,9_E`S"4YP!@T^7(,9_E``!6XP-0E.<+
M```:>___Z[@AG^4``%#C`B"/X.@/`N4!```:`0"@XYC__^NI___K``"5Y;__
M_^M19L#E``"5Y;S__^ON,]#E`C"#X^XSP.4``)7EM___Z^XST.4!,(/C[C/`
MY1P`G>4%`(#B!P%PXP8``)I8,9_E6`&?Y0,PE.<``(_@`Q"@X0PPC>4?___K
M``&@X8G__^L8P)WE."&?Y0`0G.4"((_@`!"`Y2P1G^7P#P+E`1"/X`00@.4@
M$9_E`#"@X0$0C^``$)'E"!"`Y1`1G^4!$(_@#!"@Y000H./T'P+E`1"@XQP@
MG>4"`%'A+0``N@`0H.,-`8+BZ$"?Y0`1@^<`$(WEX!"?Y01`C^`#((+B`1"/
MX.@/%.4E___K`%!0X@(``!KH#Q3E7?__ZP!0H.&X0)_E!$"/X.@/%.4]___K
MK`"?Y0``C^#K`P#K``!0XPP``!KL/Q3E``!3XP,``!J0`)_E``"/X.,#`.OL
M#P3EA#"?Y0,PC^#L#Q/E``!0XP````JC"@#K<#"?Y0,PC^#H#Q/E;___Z\G^
M_^L%`*#A(-"-XG"`O>@!X9SG`1"!X@3@H.7+___J$'L!`$@!``!$`0``#`$`
M`"0!``!XG`$`*`$``&<L``#LFP$`B"X``+1[`0!K+@``A)L!`,@4``!8FP$`
M\2L``(8K```8FP$``)L!``"PH.,`X*#C$!"?Y0$0C^`-`*#A#\#`XPS0H.$`
M``#KU'<!`!]`+>E`,)_E0""?Y0,PC^`"()/G"""-Y30@G^4"()/G#""-Y0`@
MH.,$((WE)""?Y0(PD^<$((#B`#"-Y0`0D.4(,)WE#`"=Y?/^_^N@>`$`(`$`
M``0!```0`0``2#"?Y4@`G^4#,(_@``"/X`,P@^(\()_E`#!#X`8`4^,"((_@
M'O\OD2PPG^4(T$WB`S"2YP0PC>4``%/C`0``"@C0C>(3_R_A"-"-XA[_+^'L
M>0$`Z'D!`#!X`0`<`0``3`"?Y4P0G^4``(_@`1"/X``00>!!$:#A/#"?Y:$?
M@>#!$+#A`S"/X![_+P$L()_E"-!-X@(PD^<$,(WE``!3XP$```H(T(WB$_\O
MX0C0C>(>_R_AC'D!`(AY`0#,=P$`/`$``&@PG^400"WI`S"/X``PT^5<0)_E
M``!3XP1`C^`0@+T84#"?Y0,PE.<``%/C`@``"D0PG^4#`)_GN_[_Z[[__^LX
M,)_E`S"4YP``4^,"```*+`"?Y0``C^!<_O_K`2"@XR`PG^4#,(_@`"##Y1"`
MO>@H>0$`='<!`#0!``"D>`$`%`$``&1I``#,>`$`$T`MZ5Q`G^5<,)_E!$"/
MX`,PE.<``%/C!```"DP0G^5,`)_E`1"/X```C^">_O_K0`"?Y0``C^``,)#E
M``!3XP4```HP,)_E`S"4YP0PC>4``%/C````"C/_+^$(T(WB$$"]Z*G__^KT
M=@$`.`$``(1X`0`$:0``V'4!`!@!``#P3RWIR#N?Y<@KG^4#,(_@`C"3YU7?
M3>($,(WE`#"3Y1S`@.),,8WE`#"@XPP@C>(#$9SG,1^_Y@,1@N<!,(/B$`!3
MX_G__QI`P*#C`A"@X2#@D>4T,)'E!"""X@XP(^`(X)'E`!"1Y0XP(^`!,"/@
MXS^@X0'`7.(\,(+E\O__&E0[G^4,X)WE!'"0Y0A0@.)@`97H`)"0Y0/@CN`&
M("7@!R`"X`C@CN#I[8[@!B`BX&=!H.$"X([@$""=Y03`)>`)P`S@`R""X`7`
M+.`&((+@::&@X0+`C.`4()WE"A`DX`X0`>`#((+@!2""X`00(>#NS8S@`A"!
MX&[AH.$8()WE#K`JX`RP"^`#((+@[!V!X`0@@N!LP:#A"K`KX!Q`G>4"L(O@
M#"`NX`-`A.`!(`+@"J"$X`X@(N#AO8O@"B""X&$1H.$@H)WE`4`LX`.@BN`+
M0`3@ZRV"X`[@BN!KL:#A#$`DX"2@G>4.0(3@"^`AX`.@BN`"X`[@#,"*X`'@
M+N#B383@#.".X&(AH.$HP)WE`J`KX`/`C.`$H`K@`1",X`N@*N#D[8[@`:"*
MX&1!H.$L$)WE!,`BX`,0@>`.P`S@"["!X`+`+.#NK8K@"\",X&[AH.$PL)WE
M#A`DX`.PB^`*$`'@ZLV,X`(@B^!JH:#A!!`AX#2PG>4"$('@"B`NX`.PB^`,
M(`+@[!V!X`1`B^!LP:#A#B`BX#BPG>4$((+@#$`JX`.PB^`!0`3@X2V"X`[@
MB^!A$:#A"D`DX#RPG>4.0(3@`>`LX`.PB^`"X`[@"J"+X`S@+N#B383@"N".
MX&(AH.%`H)WE`K`AX`.@BN`$L`O@#,"*X`&P*^#D[8[@#+"+X&1!H.%$P)WE
M!*`BX`/`C.`.H`K@[KV+X`$0C.!NX:#A`J`JX$C`G>4!H(K@#A`DX`/`C.`+
M$`'@ZZV*X`00(>!KL:#A`B",X$S`G>4"(('@"Q`NX`/`C.`*$`'@ZBV"X`X0
M(>!JH:#A!$",X%#`G>4$0('@"A`KX`/`C.`"$`'@"Q`AX`[@C.#B383@#N"!
MX&(AH.%4$)WE`L`JX`,0@>`$P`S@"["!X`K`+.#D[8[@"\",X&1!H.%8L)WE
M!!`BX`,PB^`.$`'@"J"#X`(0(>"$.)_E"A"!X%R@G>7NS8S@`Z"*X&[AH.$"
M((K@#J`DX`R@*N`*((+@8*"=Y>P=@>`#H(K@;,&@X01`BN`,H"[@`:`JX`I`
MA.!DH)WEX2V"X`.@BN!A$:#A#N"*X`&@+.`"H"K@"N".X&B@G>7B383@`Z"*
MX&(AH.$,P(K@`J`AX`2@*N`*P(S@;*"=Y>3MCN`#H(K@9$&@X0$0BN`$H"+@
M#J`JX`H0@>!PH)WE[LV,X`.@BN!NX:#A`B"*X`Z@).`,H"K@"B""X'2@G>7L
M'8'@`Z"*X&S!H.$$0(K@#*`NX`&@*N`*0(3@>*"=Y>$M@N`#H(K@81&@X0[@
MBN`!H"S@`J`JX`K@CN!\H)WEXDV$X`.@BN!B(:#A#,"*X`*@(>`$H"K@"L",
MX("@G>7D[8[@`Z"*X&1!H.$!$(K@!*`BX`Z@*N`*$('@A*"=Y>[-C.`#H(K@
M;N&@X0(@BN`.H"3@#*`JX`H@@N"(H)WE[!V!X`.@BN!LP:#A!$"*X`R@+N`!
MH"K@"D"$X(R@G>7A+8+@`Z"*X&$1H.$.X(K@`:`LX`*@*N`*X([@D*"=Y>)-
MA.`#H(K@8B&@X0S`BN`"H"'@!*`JX`K`C."4H)WEY.V.X`.@BN!D0:#AF+"=
MY0$0BN`$H"+@[LV,X`Z@*N`#L(O@;N&@X0H0@>`"L(O@G*"=Y0X@).`,("+@
M[!V!X`*PB^!LP:#A`Z"*X*`@G>4$H(K@#$`NX.&]B^`!0"3@`R""X&$1H.$.
MX(+@`2`LX`L@(N`"X([@I""=Y02@BN#KK8K@`R""X&NQH.$,P(+@"R`AX`H@
M(N`"P(S@J""=Y>KMCN`#,(+@:J&@X0$0@^`*,"O@[LV,X`XP(^!NX:#A#B"*
MX0,0@>`,(`+@#C`*X`,@@N&L0)WEY#6?Y>P=@>`#0(3@;,&@X0NPA.`,0([A
M"R""X`%`!.`,L`[@"T"$X;"PG>7A+8+@`["+X&$1H.$*H(O@"D"$X`&@C.$!
ML`S@`J`*X`N@BN&TL)WEXDV$X`.PB^!B(:#A#N"+X`[@BN`"H('A`K`!X`2@
M"N`+H(KAN+"=Y>3MCN`#L(O@9$&@X0S`B^`,P(K@!*""X02P`N`.H`K@"Z"*
MX;RPG>7NS8S@`["+X&[AH.$!$(O@`1"*X`Z@A.$.L`3@#*`*X`N@BN'`L)WE
M[!V!X`.PB^!LP:#A`B"+X`(@BN`,H([A#+`.X`&@"N`+H(KAQ+"=Y>$M@N`#
ML(O@81&@X01`B^`$0(K@`:",X0&P#.`"H`K@"Z"*X<BPG>7B383@`["+X&(A
MH.$.X(O@#N"*X`*@@>$"L`'@!*`*X`N@BN',L)WEY.V.X`.PB^!D0:#A#,"+
MX`S`BN`$H(+A!+`"X`Z@"N`+H(KAT+"=Y>[-C.`#L(O@;N&@X0$0B^`!$(K@
M#J"$X0ZP!.`,H`K@"Z"*X=2PG>7L'8'@`["+X&S!H.$"((O@`B"*X`R@CN$,
ML`[@`:`*X`N@BN'8L)WEX2V"X`.PB^!A$:#A!$"+X`1`BN`!H(SA`;`,X`*@
M"N`+H(KAW+"=Y>)-A.`#L(O@8B&@X0[@B^`.X(K@`J"!X0*P`>`$H`K@"Z"*
MX>"PG>7D[8[@`["+X&1!H.$,P(O@#,"*X`2@@N$$L`+@#J`*X`N@BN'DL)WE
M[LV,X`.PB^!NX:#A`1"+X`$0BN`.H(3A#K`$X`R@"N`+H(KAZ+"=Y>P=@>`#
ML(O@;,&@X0(@B^`"((K@#*".X0RP#N`!H`K@"Z"*X>RPG>7A+8+@`["+X&$1
MH.$$0(O@!$"*X`&@C.$!L`S@`J`*X`N@BN'PL)WEXDV$X`.PB^!B(:#A#N"+
MX`[@BN`"H('A`K`!X`2@"N`+H(KA]+"=Y>3MCN`#L(O@9$&@X0S`B^`,P(K@
M!*""X0ZP"N`$H`+@"J"+X?BPG>7NS8S@`S"+X`$0@^`!$(K@W#*?Y>RM@>#\
M$)WE;N&@X0,0@>`"(('@#A`DX`P0(>`!((+@`!&=Y6S!H.$#$('@!$"!X`P0
M+N`*$"'@`4"$X`01G>7J+8+@`Q"!X&JAH.$.X('@"A`LX`(0(>`!X([@"!&=
MY>)-A.`#$('@8B&@X0S`@>`"$"K@!!`AX`'`C.`,$9WEY.V.X`,0@>!D0:#A
M"J"!X`00(N`.$"'@`:"*X!`1G>7NS8S@`Q"!X&[AH.$"(('@#A`DX`P0(>`!
M$(+@%"&=Y>RMBN`#((+@;,&@X01`@N`,("[@"B`BX`)`A.`8(9WEZAV!X`,@
M@N!JH:#A#N""X`H@+.`!("+@`B".X!SAG>7A383@`^".X&$1H.$,P([@`>`J
MX`3@+N`.P(S@(.&=Y>0M@N`#X([@9$&@X0J@CN`$X"'@`N`NX`[@BN`DH9WE
MXLV,X`.@BN!B(:#A`1"*X`*@).`,H"K@[.V.X`H0@>!LH:#A*,&=Y>X=@>`#
MP(S@!$",X`K`(N`.P"S@#,"$X"Q!G>5NX:#A`T"$X`(@A.`.0"K@`4`DX.'-
MC.`$((+@84&@X3`1G>7L+8+@`Q"!X`H0@>`$H"[@#*`JX`H0@>`TH9WE;,&@
MX0.@BN`.X(K@#*`DX`*@*N#B'8'@"N".X&*AH.$X(9WEX>V.X`,@@N`$((+@
M"D`LX`%`).`$((+@/$&=Y6$1H.$#0(3@#,"$X`%`*N`.0"3@!,",X$!!G>7N
M+8+@`T"$X&[AH.$*H(3@#D`AX`)`).`$H(K@1$&=Y>+-C.`#0(3@8B&@X0$0
MA.`"0"[@#$`DX`00@>!(09WE[*V*X`,PA.`)D(/@;,&@X0[@B>`,D"+@"I`I
MX.H=@>`)X([@X>V.X`0PG>4"((C@`."`Y1`@@.5,(9WE`#"3Y0%PA^!J487@
M#,"&X`,`4N$$<(#E"%"`Y0S`@.4````*UOO_ZU7?C>+PC[WH='8!`#`!``"9
M>8):H>O9;MR\&X_6P6+*K#"?Y?!'+>D`8%#B`S"/X`:`H`$B```*F""?Y0(P
MD^<`H)/E``!:XP9`H!$"```:"H"@X1H``.H#0*#A!#"@X0$@T^0``%+C/0!2
M$_G__QH!D*#A"E"@X09`1.`%<*#A!("7Y```6.,-```*!""@X080H.$(`*#A
M.OO_ZP``4.,)```:!##8YST`4^,&```:"E!%X$51H.$!0(3B`%")Y02`B.`(
M`*#A\(>]Z`=0H.'I___JB&H!`"P!```30"WI-#"?Y30@G^4#,(_@`D"3YPT0
MH.$`,)3E!#"-Y<?__^L$()WE`#"4Y0,`4N$````*D?O_ZPC0C>(0@+WHS&D!
M`#`!``#W0"WI`&"@X0UPH.%H0)_E:#"?Y01`C^`#4)3G`#"5Y00PC>4'$*#A
M!@"@X;+__^L``%#C!```&@0@G>4`,)7E`P!2X0H```IZ^__K,#"?Y0`@G>4#
M,)3G`#"3Y0(Q@^`$()/E``!2XP0@@^3[__\:Z___Z@S0C>+P@+WH?&D!`#`!
M```L`0``\$\MZ0%0H.'`D9_EP#&?Y0F0C^`#,)GG%-!-X@`PC>4`,)/E`&"@
MX0PPC>4`,-'E/0!3XP%0@0(%`*#A6/O_ZP@0C>(`<*#A!@"@X8C__^L`0%#B
M#@``"E'[_^L``%?A,P``B@%`1.(!,-7D``!3XP$PY.7[__\:``"@XP`PG>4,
M()WE`#"3Y0,`4N%-```*1OO_ZSPQG^4#H)GG`+":Y00QF^<``%/C#0``&B@Q
MG^4#,(_@`""3Y0``4N,"((3B"0``"@(1H.$+`*#AC/K_ZP``4.,``(KE$```
M&@``X./E___J`4"$XNS__^H!$*#C`B&@X0(`H.$`$(/E!""-Y:_Z_^L`@%#B
M\___"@0@G>4+$*#A""!"XJSZ_^L`@(KE`!"@XP`PFN4!((3B`A&#YPA`C>4&
M,*#A`R"@X0$0TN0``%'C/0!1$QH``!J$()_E!C!#X`)`F><"`(?B`P"`X`B@
MG>4`D)3EE?K_ZPH!B><``%#C`#"4%0@@G14",9,7U?__"@$@UN0#$*#A``!2
MXST`4A,!(,'D"```&CT@H.,`(,/E`2#5Y```4N,!(./E^___&J___^H",*#A
MW?__Z@$PH.'N___J%-"-XO"/O>CX:`$`,`$``"P!```8:@$`\$\MZ2@QG^4H
M(9_E`S"/X`)@D^=TT$WB`#"6Y0!04.)L,(WE$P``"@`PU>4``%/C$```"C'Z
M_^L`<%#B#0``"O2`G^7TD)_E]*"?Y0B`C^`)D(_@"J"/X`<`H.%.^O_K``!0
MXP@``!H'`*#A:_K_ZP4`H.&N^O_K;""=Y0`PEN4#`%+A*```"M#Z_^L30(#B
M"!"@X00`H.$\^O_K``!0X^S__PH)$*#A!`"@X3?Z_^L``%#CY___"@4`H.'`
M^O_K`+"@X00`H.&]^O_K``"+X`(`@.)"^O_K`+"@X00PH.$%(*#A"A"@X:GZ
M_^L-$*#A"P"@X9KZ_^L!`'#C"P"@X0<```H0,)WE#SH#X@$)4^,#```:N?__
MZPL`H.&-^O_KS/__ZBOZ_^OZ___J=-"-XO"/O>@<9P$`,`$``*D8``"D&```
MHQ@``'!`+>E\,)_E?""?Y0,PC^`"0)/G`%"@X0``E.6'^O_K2A^`X@4`H.$G
M^O_K``!0XP$```H``*#C<("]Z```E.5^^O_K.#&0Y0\Z`^(!"5/C!0``&@(0
MH.,%`*#AY/G_ZQ`/;^&@`J#A<("]Z```E.5R^O_K.#&0Y0\Z`^(*"E/CZ___
M&O+__^K490$`)`$``!-`+>D\0)_E/#"?Y01`C^`#,)3G``"3Y63Z_^LL,)_E
M+!"?Y0,PE.<!$(_@!#"-Y2`PG^4$()WE`S"/X`C0C>(00+WH4_K_ZD1E`0`D
M`0``0`$``/T6``"X%@``$T`MZ4PPG^5,()_E`S"/X`)`D^<``)3E3?K_Z^#_
M_^L``)3E2OK_ZP`@H.,L,)_E!""-Y2@0G^4H()_E`S"/X``PC>4"((_@`1"/
MX+/Y_^L(T(WB$("]Z.AD`0`D`0``&QD``)T6``!8$@``\$$MZ1@QG^48(9_E
M`S"/X`)PD^<"VDWB&-!-X@(JC>(`,)?E%"""X@`P@N6L^?_K]#"?Y?1@G^7T
M()_E`S"/X`R`C>(`,(WE`B"/X``PH.$&$*#A"`"@X9+Y_^L!,(#B!@!3X0``
M`)KP`/#G``!0XP@``*H`,*#C`P"@X0(ZC>(4,(/B`""3Y0`PE^4#`%+A(```
M"B7Z_^L!6HWB$%"%X@$JH.,%$*#A"`"@X=3Y_^L`0%#B[O__N@$`A.*@^?_K
M`#!0XNK__PH%`%/A`@``*@0@@^`"`%7AXO__.@4`4^$"``":!""%X`(`4^'=
M__\Z!@!4X=O__\H$(*#A`P"@X040H.']^?_K`""@XP`PH.$$(,#GU___Z@+:
MC>(8T(WB\(&]Z'QD`0`P`0``7A8```$0``!&%@``L/__ZO!/+>GH<9_EZ#&?
MY0=PC^`#@)?G`=I-XA303>(`4*#AU`&?Y0`PF.4!*HWB#"""X@``C^`!0*#A
M`#""Y4S^_^LO$*#C`)"@X04`H.&.^?_K``!0XPL```J@`9_E!1"@X0``C^!V
M_O_K`3J-X@PP@^(`()/E`#"8Y04`H.$#`%+A6```"MKY_^L%`*#AU?G_ZVP1
MG^4`H*#A`1"/X`0`H.&^^?_K`$"@X5BQG^4,8(WB"["/X```5./F__\*`##4
MY0``4^,+0*`!``!9XPD```H$$*#A"0"@X37Y_^L``%#C!```&B`1G^4!$(_@
MJ_G_ZP!`H.'N___J!`"@X;GY_^L`$*#C``"$X`$P4.4$($#@+P!3XQ$```H!
M,(KB`C"#X`$*4^/+__^JX#"?Y>`@G^4#,(_@`#"-Y010C>4$,*#A`B"/X`$:
MH.,&`*#A!OG_ZP$`@.(!"E#C`@``FO``\.<!$&#EY___ZJ@PG^4#0)?G``"4
MY8SY_^M*'X#B!@"@X8#Y_^L``%#C$@``&@``E.6%^?_K.#&0Y0\Z`^(""5/C
M#```&@$0H.,&`*#AZ_C_ZP``4.,'```:7`"?Y080H.$``(_@'O[_ZP8`H.$?
M^?_K`%"@X:/__^I`$)_E``"@XP$0C^#`___J`=J-XA30C>+PC[WH0&,!`#`!
M```R%0``"Q4``.`4``!I%```D!0``$H4```5%0``)`$``*L3``"8$P```#"@
MX0$@T^0``%+C````&A[_+^$O`%+C`P"@`?C__^IP0"WI`$!0X@(```H`4-3E
M``!5XP,``!KD`)_E``"/X'!`O>CX^/_J7?G_ZP$`0.(``(3@``!4X0`@H.$5
M```J`##0Y0$@0.(O`%/C#P``"@``5.$`(*#A#@``*@`PTN4!`$#B+P!3X_C_
M_QH!($+B`@!4X1```#H$($+@`C""X@$*4^,2``":``"@XW"`O>@"`*#AYO__
MZ@``5.'R__\:+P!5XUP`GP4``(\`V___"E0`G^4``(_@V/__Z@`PTN4!$$+B
M+P!3X^K__QH!(*#AYO__Z@$@@N(!"E+C````FO``\.<D4)_E!!"@X050C^`$
M4(7B!0"@X>3X_^L%`*#A<("]Z+D2```M$@``@A(``-QA`0!P0"WIR#&?Y<@A
MG^4HT$WB`S"/X`)`D^<-4*#A#2"@X;01G^4`,)3E`1"/X"0PC>4JP('B"C"!
MX@+@H.$``)/E!!"3Y0@P@^(#`*[H#`!3X0X@H.'W__\:L##3X7P!G^6P,,[A
M``"/X'W]_^MP`9_E<&&?Y0``C^!Y_?_K:`&?Y09@C^```(_@=?W_ZUP!G^4`
M`(_@<OW_ZU0!G^4``(_@;_W_ZTP!G^4``(_@;/W_ZT0!G^4``(_@:?W_ZSP!
MG^4``(_@9OW_ZP8`H.%D_?_K+`&?Y0``C^!A_?_K)`&?Y0``C^!>_?_K'`&?
MY0``C^!;_?_K%`&?Y0``C^!8_?_K#`&?Y0``C^!#_?_K`!!0X@$```H&`*#A
M<_W_Z_0`G^4``(_@//W_ZP`04.("```*Y`"?Y0``C^!K_?_KW`"?Y0``C^`T
M_?_K`!!0X@P```K,`)_E``"/X&/]_^O$$)_EQ`"?Y0$0C^```(_@7OW_ZR0@
MG>4`,)3E`P!2X1(```K%^/_KI`"?Y0``C^`B_?_K`!!0XI@`GQ4``(\0[?__
M&I`0G^4*(*#C`1"/X!$`A>)$^/_K``!0X^?__QIX`)_E&Q"%X@``C^#B___J
M*-"-XG"`O>CD7P$`,`$``&P1``#`$0``N1$``.L1``"Q$0``KA$``*D1``"M
M$0``5A$``*$1``"A$0``,Q$``),1``"0$0``CQ$``(01``""$0``@1$``+80
M``")$0``W1```$D1``#)$```.A$``)T0```00"WI3#"?Y0,PC^``,)/E`0!S
MXPP``!H\`)_E``"/X.W\_^L``%#C!```"@``T.4``%#C,`!0$P$`H!,``*`#
M&#"?Y0,PC^```(/E$#"?Y0,`G^<0@+WH_%X!``40``#`7@$`M%X!`!!`+>E]
M^/_K)?C_ZP``4.,``)`5$("]Z/!/+>GL,)_E[""?Y0,PC^`"@)/GY,"?Y2S0
M3>(,P(_@`#"8Y0C@C>($P(SB`%"@X20PC>4/`+SH#P"NZ`<`G.@'`([HN*"?
MY;BPG^4(D(WB"J"/X`NPC^`$0)GD``!4XP0``!HD()WE`#"8Y0,`4N$>```*
M6/C_ZP0`H.&V_/_K`&!0X@40H.$"```*`##6Y0``4^,"```:!`"@X>+\_^OL
M___JZ??_ZP``4./I__\:!0"@X47X_^L`<*#A!@"@X4+X_^L``(?@`@"`XL?W
M_^L`<*#A"Q"@X0!@C>4*,*#A!2"@X2WX_^L'$*#AZ?__ZBS0C>+PC[WH*%T!
M`#`!``!H7@$`$`\``.D/``#P3RWI.'F?Y3@YG^4'<(_@`S"7YP+93>+\T$WB
M*,F?Y10PC>4"*8WB`#"3Y?A`C>(,P(_@]"""X@`P@N4L8(SBU#!$XB`@C.*\
MX$3B`%"@X0<`DN@'`(/H#P"VZ`\`KN@#`);HR#!$XD3`C.(#`([H!P"<Z`<`
M@^C0")_E``"/X'+\_^L`8%#B#P``"@`PUN4``%/C#```"I7__^L&`*#AH??_
MZP!PH.$".8WB]#"#X@`@D^44,)WE!P"@X0`PD^4#`%+A&P(`"@#X_^N"___K
M`&!0XLB`1`)=```*!@"@X??W_^N``*#A`0"`XGSW_^L`H*#A`("@X528G^4!
M8$;B"9"/X`$@]N4``%+C5@``&KR`1.($8)CD``!6XPP```H&`*#A2?S_ZP!@
M4.+X__\*`##6Y0``4^/U__\*0?W_ZP``4./R__\*!@"@X7;W_^L`8*#AU)!$
MX@``5N,%```:!("9Y```6.,"```*`##8Y0``4^-!```:!@"@X=#W_^L`@*#A
M"@"@X<WW_^L`@(C@`8N(X@2`B.((`*#A4/?_ZP"0H.&L-Y_EK!>?Y0,PC^``
M,(WEI#>?Y08@H.$#,(_@`1"/X`2@C>6Q]__K!QV@XPD`H.&<]__K`0!PXR\`
M`!J6]__K`#"0Y1$`4^,K```*;#>?Y0!`E>4#,)?G`#"3Y1`PC>6-]__K6!>?
MY0`PD.4$(*#A`#"-Y0$0C^`),*#A$`"=Y7#W_^L`<*#CG?__Z@;\_^L`,%#B
M!0``"@`PT^4``%/C`@``"C?W_^L`8%#BH?__&@0`F.0``%#C\___&@1GG^4&
M8(_@F___Z@@`H.$)$*#AAO?_ZP*`B.*@___J"`"@X>_\_^L``%#CL___"@@`
MH.$D]__K`&"@X:W__^K(-I_E`Z"7YP``FN5U]__K2A^`X@D`H.$5]__K`&!0
MXI,!`!H``)KE;O?_ZS@QD.4/.@/B`0E3XXT!`!H``)KE:/?_ZT"QD.5[]__K
M``!;X8<!`!H``)KE8O?_ZS@QD.6#.Z#AHSN@X0<-4^.``0`:"`"@X?+V_^L`
M<*#A4`:?Y0``C^#)^__K``!0XP8```H`@)7E_/;_ZP`0H.$(`*#A9?W_ZP"`
M4.(````:`("5Y0@`H.%:]__K`P!0XP"@H.$:``#:#!:?Y00`0.(!$(_@``"(
MX,7V_^L``%#C$P``&@0`6N,#```*"J"(X`4P6N4O`%/C#0``&@10E>4``%7C
M"@``"@4`H.%%]__K`P!0XP8``)K`%9_E!`!`X@$0C^```(7@L?;_ZP``4.,%
M@*`!I_[_ZP"@4.(E`0`:"A"@X0@`H.'3]O_K`+!0XB`!``H"4*#C`##@XQ$@
MX.,`4(WE!(!$XIOV_^L&(*#C"!"@X0L`H.$`]__K!#!4Y0``4^,K```:`S!4
MY4,`4^,H```:`C!4Y4$`4^,E```:`3!4Y4,`4^,B```:`##4Y4@`4^,?```:
M`3#4Y44`4^,<```:`##@XSD@X.,`4(WE"P"@X8#V_^LI(*#C"!"@X0L`H.'E
M]O_K"2"@X?`TG^7P%)_E`S"/X`0PC>7H-)_E`("-Y0,PC^`!$(_@!P"@X?CV
M_^L)`*#AY_;_Z\P$G^4'$*#A``"/X)7[_^L'`*#AB/[_Z_3^_^H`4*#C`#"@
MXP!0C>4`(*#C"P"@X6+V_^N<-)_E5&"-XJ0P!.64-)_ED%`$Y:`P!.6,-)_E
MC%`$Y9PP!.6$-)_E2%`$Y9@P!.5\-)_EE#`$Y5PPAN(8,(WE`BF@XP@0H.$+
M`*#AM_;_ZP!04.)E``#*"P"@X:WV_^M_$.#CD%`4Y8@@1.*E,:#A/S`#X@$`
M@^(X`%#CC(`4Y0,0PN>Z``#:'+"&XD`@8.(`$*#C``"+X$WV_^L&`*#A!?C_
MZS@@H.,`$*#C"P"@X4?V_^LH/*#A4#!$Y2@XH.%/,$3E*#2@X4XP1.4E/*#A
M3#!$Y24XH.%+,$3E!@"@X24TH.%-@$3E2C!$Y4E01.7Q]__KI#`4Y;ACG^4C
M+*#A1"!$Y2,HH.%#($3E03!$Y2,DH.&@,!3E0B!$Y2,LH.%`($3E(RB@X3\@
M1.4],$3E(R2@X9PP%.4^($3E(RR@X3P@1.4C**#A.R!$Y3DP1.4C)*#AF#`4
MY3H@1.4C+*#A."!$Y2,HH.$W($3E-3!$Y2,DH.&4,!3E-B!$Y2,LH.$T($3E
M(RB@X3,@1.4C)*#A,B!$Y3$P1.5$@$3B!F"/X#!01.(*(-CGB@"%X`80H.$!
MH(KB>_;_ZQ0`6N/X__\:`#"@XP@P1.7L,I_E[!*?Y0,PC^`$,(WEY#*?Y0!0
MC>4#,(_@"2"@X0$0C^!R___JD#`4Y84A@^`"`%/AC#`4A9`@!.4!,(."C#`$
MA8PP%.5((!3EI3Z#X```4N.,,`3E.```"D`P8N(<`(;B`P!5X0(`@.`%,*"Q
M"`!0X0(``"H#((#@`@!8X00``#H(`%#A`P``F@,@B.`"`%#A````*O``\.<"
M"5/C_/__B@,@H.$($*#A$#"-Y4WV_^M((!3E$#"=Y0(@@^!``%+C2"`$Y6K_
M_QH#$(C@!@"@X1`0C>4#4$7@A/?_ZQ`0G>4<,(;B$#"-Y3\`5>,4``#*'#"&
MX@,`4>$"``":!3"#X`,`4>'B__\Z'#"&X@,`4>$"```J!2"!X`(`4^'<__\Z
M1`!5X]K__XH%(*#A'`"&XBSV_^M(4`3E3?__Z@@0H.'F___J$#"=Y1@@G>4#
M`%'A`#"@DP$PH(,"`%'A`#"@(P``4^/*__\:$#"=Y0,`4>%`,('B`@``*A`@
MG>4#`%+AP___.D`@H.,0`)WE'#"-Y13V_^L&`*#A5/?_ZT!01>(<$)WES___
MZAPPAN(X(&#B`!"@XP``@^!)___J.!&?Y3@!G^4!$(_@``"/X*7Z_^M]]?_K
M*#&?Y2@1G^4#,(_@"0"-Z"`QG^4)(*#A`S"/X`$0C^`'`*#A]_7_ZPQ!G^4,
M49_E#(&?Y01`C^`%4(_@"("/X`<=H.,'`*#AW/7_ZP$`<./S_O\:UO7_ZP`P
MD.41`%/C[_[_&F/U_^L!8(;B00&-Z`0PH.$)(*#A!1"@X0<`H.'@]?_K[?__
MZD@PG^6T$)_E`P"7YP`@E>4),*#A`1"/X```D.6M]?_K._[_Z@+9C>+\T(WB
M\(^]Z!Q<`0`P`0``2%T!`,(-```J#@``C`T``&\-``":#```"`$``"4-``"_
M#```)`$``)0-```,#```P0L``/L+``#>"@``M@D``'X)```!(T5GB:O-[_[<
MNIAV5#(0\.'2PZ((``#/"0``K@@``(H'``"E!@``%08``/<'``#I!@``L@4`
M`)8%``#;!@``PP<``(@&``#W3RWI/#.?Y3PCG^4#,(_@`D"3YP``E.6D]?_K
M`%"@X0``E.6A]?_K8##0Y1P#G^5A,,7E``"/X`[Z_^L``%#C!0``"@`PT.4Q
M`%/C`@``&@$PT.4``%/C````"G[\_^L``)3ED?7_Z^02G^4+,*#C`2"@XP$0
MC^!!]?_K``!0XQT``!H``)3EB/7_Z\02G^4#,*#C`2"@XP$0C^`X]?_K`%!0
MXD\``!H``)3E?_7_ZZ02G^4#,*#C`2"@XP$0C^`O]?_K`%!0XF,```J,`I_E
M``"/X.?Y_^L`8%#B4P``"@``E.5Q]?_K!B"@X0PPE>4`$)/E*/7_ZU<``.H!
M4*#C`)"@XPPPD.54@I_E&'"3Y5"BG^4(@(_@]#\8Y0%@1>(#`%7A!P``J@``
ME.5?]?_K!Q"@X0DPH.$&(*#AYO3_ZP`04.(0```:'#*?Y0,PC^#T+Q/E`2!"
MX@(`5N$!8*`#`U"@`<;__QKT/Q7E`P!6X</__ZH``)3E3/7_ZP<0H.&K]/_K
M`6"&XO;__^KP/QCE`""1Y06QD^<(,)+E"C`#X`$+4^,,$)(%"```"@``E.4$
M$(WE/?7_ZP00G>4",*#C`!"1Y0D@H.%$]?_K`!"@X0L`H.&W]/_K``!0X]G_
M_QH!4(7BR___Z@``E.4O]?_K##"5Y70AG^4`$)/E`B"/X.7T_^L,,)7E`#"3
MY0@PD^4!!1/CH___"@``E.4C]?_K##"5Y0`0D^6Q]/_KG?__ZN3Z_^L`8%#B
M``"4Y2@```H:]?_K##"5Y08@H.$`$)/ET?3_ZP8`H.$(]?_K``"4Y1+U_^L`
M4*#A``"4Y0_U_^O\$)_E`2"@XP$0C^!U]/_K\""?Y0`0H.$"((_@!0"@X<'T
M_^L``)3E!/7_ZP`PH.-A,,#ET`"?Y=!`G^4``(_@</G_ZP1`C^```%#C[`\$
MY0X``!KP#Q3EUOS_ZP``4./L#P3E"0``&J0`G^4``(_@:/3_Z_'T_^N8,)_E
M`S"/X/`O$^4,,)7E`""2Y7O__^J$0)_E!QV@XP1`C^#L#Q3EU_3_ZP$@@.(1
M`%#C`0!2$P`PH.$%``":\!\4Y5P`G^7L+Q3E`!"1Y0``C^!1]/_K#-"-XO"/
MO>A$4@$`)`$``&T$``"W!0``F`4``#$$``"?`P``]'(!```$(`"\<@$`-@0`
M`+\#``#$`P``N@$``%1Q`0!V`P``''$!``!Q`0`[`P``<$`MZ0!`H.%I^__K
M8/O_ZP!0H.$[_/_K``!0XP``5!-P@+T(`##4Y0``4^-P@+T('!"?Y04`H.$!
M$(_@9?3_ZP``5>%P@+T8!`"@X7!`O>C/^?_JE`$```%`+>D!0+WH'O\OX7!E
M<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```+BX`
M)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`!005)?4%)/1TY!
M344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!
M4E]#04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`
M4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`4UE35$5-`"4P,G@`)7,E
M<R5S)7,`<&%R+0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`'!A<FP`+G!A<@`E<R5S8V%C:&4M
M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!!4D=6`!@`<&5R;`!005(Z
M.E!A8VME<CHZ5D524TE/3@`Q+C`S-0!5;F%B;&4@=&\@8W)E871E(&-A8VAE
M(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`%5315(`55-%
M4DY!344`5$5-4$1)4@!435``+W1M<`!,24)0051(`$193$1?3$E"4D%265]0
M051(`%-(3$E"7U!!5$@`979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA
M;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E
M<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![
M("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER
M("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN
M,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@
M)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T
M;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I
M;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[
M(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G
M(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O
M;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L
M)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@
M/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D[
M"F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R
M;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B![
M"DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES
M=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*
M0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM0
M05)?05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@
M>PIF;W(@*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?
M05)'5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(
M*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S
M970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]
M("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=
M.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q
M6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A
M9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN
M(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@
M)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N
M;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(
M+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M
M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E
M7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L
M;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE
M*"1E>'0L("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN
M="`D;W5T("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M
M93L*?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL
M96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F
M=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@
M86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]
M("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@
M;W(@9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L
M;W-E("1O=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]
M"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@
M/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]
M"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@
M;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E
M<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD
M:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@
M:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H
M*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P
M*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T
M96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2![
M"F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*
M8VQO<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@
M)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A
M)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F
M('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R
M"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P
M87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H
M)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G
M*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G
M*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@
M/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L
M;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF
M("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B
M6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G
M*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@
M)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0
M)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D
M9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'
M5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D
M<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H
M)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G
M)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D
M+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P
M87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R
M(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP
M,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@
M/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD
M=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC
M(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*
M)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[
M)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L
M=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F
M:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C
M72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]
M"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H
M;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO
M="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q
M*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L
M("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I
M;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q
M*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^
M<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I
M.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A
M)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@
M>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S
M=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N
M(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE
M;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M
M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN
M(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A
M.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*
M979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R
M.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T
M96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]
M"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0
M("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED
M.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R
M;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@
M*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS
M>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*
M)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H
M)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D
M97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE
M(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]
M"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL
M96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX[
M"GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O
M7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D
M<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI
M;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?
M,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E
M;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM0
M05)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C
M;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@
M/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B
M(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT
M("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U
M8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@
M9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB
M97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A
M<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E
M<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T
M;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]2
M13HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]2
M13HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.
M1%]?"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````*P7```@%P````````$````!`````0```/4"```/````I0,`
M``P```!D$```#0```$A````9````N(T!`!L````$````&@```+R-`0`<````
M!````/7^_V\L`0``!0```*@(```&````"`(```H```"B!```"P```!`````5
M``````````,```"TC@$``@```/`!```4````$0```!<```!T#@``$0```$P-
M```2````*`$``!,````(````&`````````#[__]O`0``"/K__V\6````````
M`````````````````````````````````````````````````,2-`0``````
M`````'`0``!P$```<!```'`0``!P$```<!```'`0``!P$```<!```'`0``!P
M$```<!```'`0``!P$```<!```'`0``!P$```<!```'`0``!P$```<!```'`0
M``!P$```<!```'`0``!P$```<!```'`0``!P$```<!```'`0``!P$```<!``
M`'`0``!P$```<!```'`0``!P$```<!```'`0``!P$```<!```'`0``!P$```
M<!```'`0``!P$```<!```'`0``!P$```<!```'`0``!P$```<!```'`0``!P
M$```<!```'`0``!P$```<!```'`0``!P$```;!,`````````````2$``````
M`````````````&00````````````````````````````````````````````
M`````````````)`!`/____]'0P``/4,``$I#``!`0P``14,``%=#````````
M.$,``(%`````````=D$``&]!```L0P``C$$``#1#````````'D,``"-#````
M````8D,``$=#0SH@*$%L<&EN92`V+C(N,2D@-BXR+C$@,C`Q-C`X,C(`03(`
M``!A96%B:0`!*`````4V6DL`!@<(`0D!"@(2!!,!%`$5`1<#&`$:`AP!'@0B
M`40!`"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S
M```````````````````````````````````````````````````````+````
M`0````(````4`0``%`$``!@```````````````$`````````$P```/;__V\"
M````+`$``"P!``#<`````P`````````$````!````!T````+`````@````@"
M```(`@``H`8```0````#````!````!`````E`````P````(```"H"```J`@`
M`*($``````````````$`````````+0````D````"````3`T``$P-```H`0``
M`P`````````$````"````#8````)````0@```'0.``!T#@``\`$```,````1
M````!`````@````_`````0````8```!D$```9!````P```````````````0`
M````````.@````$````&````<!```'`0``#\`@`````````````$````!```
M`$4````!````!@```&P3``!L$P``W"P`````````````!`````````!+````
M`0````8```!(0```2$````P```````````````0`````````40````$````"
M````5$```%1```"*0``````````````!`````````%D````!`````@```."`
M``#@@```!```````````````!`````````!C````#@````,```"XC0$`N(T`
M``0```````````````0````$````;P````\````#````O(T!`+R-```$````
M```````````$````!````'L````!`````P```,"-`0#`C0``!```````````
M````!`````````"`````!@````,```#$C0$`Q(T``/`````$``````````0`
M```(````B0````$````#````M(X!`+2.``!,`0`````````````$````!```
M`(X````!`````P````"0`0``D```6```````````````!`````````"4````
M"`````,```!8D`$`6)```#`0``````````````0`````````F0````$````P
M`````````%B0```C```````````````!`````0```*(````#``!P````````
M``![D```,P```````````````0`````````!`````P``````````````KI``
5`+(```````````````$`````````
